;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
;;;             cardiological anamnesis instance         ;;;;
;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;

;;; needs Suregen, Dictionary, GermanDict, lexicalSemantics, aggregation

(EVAL-WHEN (:compile :compile-toplevel :load :load-toplevel :execute)
  

    
  (in-package :common-graphics-user)
  
  (DECLAIM (SPECIAL Ex_main *patient* Doc_main *LexicalAssertions*))
  
    
  
  ;;; ************************************************************************
  ;;; *******************           A-Box       ******************************
  ;;; ************************************************************************
  
  (SuregenConcept P_CA :is-a SuregenProcess) 
  
  ;;; ************************************************************************
  ;;; ************************      P0: Orte        **************************
  ;;; ************************************************************************  
   
  (SuregenNamedInstance i-praekordial SuregenLocation-s :description "prkordial") 
  (SuregenNamedInstance i-linksthorakal SuregenLocation-s :description "linksthorakal")  
  (SuregenNamedInstance i-retrosternal SuregenLocation-s :description "retrosternal")
  (SuregenNamedInstance l-pretibial SuregenLocation-s :description  "prtibial")
  (SuregenNamedInstance l-ankle SuregenLocation-s :description "Knchel")
  
  (SuregenNamedInstance l-generalized SuregenBodyPart :name "generalisiert" :description "generalisiert" :singleP T)
  
  (AssertThat :a "dem" :which (Is-Located l-ankle) :is-called "Kncheldem")
  (AssertThat :an "dem" :which (Is-Located l-os_sacrum) :is-called "Sakraldem")
  (AssertThat :an "dem" :which (Is-Located l-eyelid) :is-called "Liddem")
  ;;;(AssertThat :an "dem" :which (Is-Located l-generalized) :is-called "Hydrops anasarka")
  
  (SuregenConcept cardiac_symptom :is-a Suregensymptom
                  :has (category description grade))
  
    (ToDescribe :the :normal :of-a cardiac_symptom :as :NP
              :use (LET-IF* freq (EQUAL (my :grade) 1)
                            (Noun-Phrase :noun (my-intern 'Description) 
                                         :article :negative
                                         :numerus (my-intern 'DescribeAbsenceInPlural))))
  
  ;;; ************************************************************************
  ;;; ********************     P1: Sozialanamnese     ************************
  ;;; ************************************************************************
  
  (SuregenConcept P1_Sozialanamnese 
                  :has ((Beruf :INITFORM NIL) BeruflicherStatus beruflicherStatusSeit au_berentetSeit))
  
  (Todescribe :a p1_sozialanamnese :use (DescribeS (Occupationalstatus *patient*)))
  
  ;;; ************************************************************************
  ;;; ******************      P2: jetzige Beschwerden     ********************
  ;;; ************************************************************************
  
  (SuregenConcept P2_jetzigeBeschwerden  
                  :has (Beschwerden))
  
  (ToDescribe :a P2_jetzigeBeschwerden :as :MC
              :use (LET-CASE beschwerden (my :beschwerden)
                             (:NONE  (Main-clause-simple
                                      :subject (Make-Reference :patient) ;;; 04.11.2002 :mode :personal)                     
                                      :adverbial "beschwerdefrei"
                                      :predicate "sein"
                                      :sentenceP T))
                             ('NIL "")                   
                             (OTHERWISE (Main-clause-simple
                                         :subject (Make-Reference :patient ) ;;; 04.11.2002 :mode :neutral)                     
                                         :adverbial "aktuell"
                                         :predicate "angeben"
                                         :object beschwerden
                                         :sentenceP T
                                         :constType (:compsepAdvFirst)))))
  
  
  (SuregenNamedInstance i-jetzigeBeschwerden P2_jetzigeBeschwerden)
  ;;; ************************************************************************
  ;;; ********************      P3: Thoraxschmerz     ************************
  ;;; ************************************************************************  
  
  ;;; (Describelist 'P3_Thoraxschmerz :as :MC :trans T)
  
  (SuregenConcept P3_Thoraxschmerz :is-a SuregenPain
                  :has (NYHA NitroSensitive NitroHelpsAfter))
  
  ;;;; playground
  (ToDescribe :a P3_Thoraxschmerz :as :MC 
              :use (SyntacticalSequenceType :sentences NIL :NOSPEC                                   
                                            (Main-clause-simple :subject (Make-Reference :patient :mode :pronoun)
                                                                :predicate "klagen ber"
                                                                :object  (noun-phrase 
                                                                          :noun "Schmerz"
                                                                          :numerus :plural
                                                                          :supplement (Enum :nojunctor :positive
                                                                                            (Describes it :facet :radiation :as :RC)))
                                                                :sentenceP T)))
  ;;;; end playground
  
  (ToDescribe :a P3_Thoraxschmerz :as :MC 
              :use (LET-IF* painspecs (NULL (OR (LocList (Location it)) (itemlist (triggers it))
                                                (LocList (Radiation it)) (itemlist (quality it))))
                            (IF (mygreaterP (my :NYHA) 1)
                                (noun-phrase :supplement-pre "formal "
                                             :noun "Angina pectoris"
                                             :supplement (DescribeS it :facet :nyha))
                              (Main-clause-simple :subject (Noun-phrase :noun "Angina pectoris"
                                                                        :article :indefinite
                                                                        :adjective "typisch")
                                                  :adverbial "nicht"
                                                  :predicate "bestehen"
                                                  :sentenceP T))                                          
                            (SyntacticalSequenceType :sentences NIL NIL                                  
                                                     (Main-clause-simple :subject (Make-Reference :patient);;; 04.11.2002  :mode :pronoun)
                                                                         :predicate "klagen ber"
                                                                         :object  (noun-phrase 
                                                                                   :noun "Schmerz"
                                                                                   :numerus :plural
                                                                                   :supplement-pre (Enum :telegraphic :positive
                                                                                                         (Describes it :facet :quality :as :attribute)
                                                                                                         (Describes it :facet :location :as :attribute))
                                                                                   :supplement (Enum :nojunctor :positive
                                                                                                     (Describes it :facet :radiation :as :RC)
                                                                                                     (noun-phrase :supplement-pre "formal" :noun (Describes it :facet :NYHA) :numerus :singular)))
                                                                         :sentenceP T)
                                                     (Describes it :facet :trigger :as :MC)
                                                     (Describes it :facet :nitrosensitivity :as :MC))))
  
  (ToDescribe :the :nyha :of-a P3_Thoraxschmerz 
              :use (LET-IF* nyhaQ (CASE (my :Nyha) 
                                    ((0 1) NIL)(2 "I") (3 "II") (4 "III") (5 "IV"))
                            (Phrase "NYHA " nyhaQ)))
  
  (ToDescribe :the :nitrosensitivity :of-a P3_Thoraxschmerz :as :MC
              :use (LET-case nitro (my :nitrosensitive)
                             (0 :fail) 
                             (2 (Main-Clause-simple :subject (Noun-form "Nitroprparat" :numerus :plural)
                                                    :predicate "helfen" :sentencep T
                                                    :adverbial (LET-IF* interval (my :nitrohelpsafter)
                                                                        (IF (my-ZEROP interval) "sofort"
                                                                          (Noun-Phrase :noun (Unit-form interval :min T T) 
                                                                                       :preposition "nach")))))
                             (1 (Main-Clause-simple :subject (Noun-form "Nitroprparat" :numerus :plural)
                                                    :predicate "helfen" 
                                                    :adverbial "nicht"
                                                    :sentencep T))))
  
  (ToDescribe :the :trigger :of-a P3_Thoraxschmerz :as :MC
              :use (LET* ((atrest (itemPresentP (Triggers it) s-atRest))
                          (belPsy (itemPresentP (Triggers it) s-emotionalStress))
                          (belPhys (itemPresentP (Triggers it) s-physicalExercise))
                          (belBoth (AND belPhys belPsy)) (belAny (OR belPhys belPsy))
                          (PP (itemPresentP (Triggers it) s-postprandial))
                          (cold (itemPresentP (Triggers it) s-cold))
                          (weather (itemPresentP (Triggers it) s-chgWeather))
                          (night (itemPresentP (Triggers it) s-atnight)) (anyT (OR belAny atrest PP cold night weather)))
                     (WHEN anyT (IF (OR belAny atrest)
                                    `(Main-clause-simple
                                      :subject (noun-phrase :noun "Beschwerde" :numerus :plural :article :demonstrative)
                                      :predicate "auftreten"
                                      :attribute-pre (GOV-Constituent ((:syntacticalRole :attribute-pre))
                                                                      ,@(APPEND (IF atrest (COND (belBoth '("unter Ruhebedingungen und bei Belastungen"))
                                                                                                 (belpsy '("in Ruhe und bei psychischen Belastungen"))
                                                                                                 (belphys '("in Ruhe und bei krperlichen Belastungen"))
                                                                                                 (T '("schon in Ruhe")))
                                                                                  (COND (belBoth '("bei krperlichen und psychischen Belastungen"))
                                                                                        (belpsy '("bei psychischen Belastungen"))
                                                                                        (belphys '("bei krperlichen Belastungen"))))))
                                      :apposition ,(WHEN (OR pp cold night weather)
                                                     `(GOV-Constituent :nospec 
                                                                       "darber hinaus" ,(EnumFromList :emphasize :positive (MAPwith 'Describes (LIST pp cold night weather)
                                                                                                                                     :as :attribute))))
                                      :consttype (:compseparate) :sentenceP T)
                                  `(Main-clause-simple
                                    :subject (noun-phrase :noun "Schmerz" :numerus :plural :article :demonstrative)
                                    :predicate "auftreten"
                                    :attribute (GOV-Constituent ((:syntacticalRole :attribute)) (EnumFromList :emphasize :positive (MAPwith 'Describes ',(LIST pp cold weather night )
                                                                                                                                            :as :attribute)))
                                    :consttype (:compseparate) :sentenceP T)))))
  
  (SuregenNamedInstance i-Thoraxschmerz P3_Thoraxschmerz)
  
  ;;; ************************************************************************
  ;;; ********************     P4: Rhythmusstrungen     *********************
  ;;; ************************************************************************ 
  
  (SuregenConcept cardiac_symptom_rhythm :is-a cardiac_symptom)
  
  (SuregenNamedInstance s-cardiac_symptom_rhythm cardiac_symptom_rhythm :category :rythmDist :description "Herzrhythmus")
  
  (SuregenConcept palpitation :is-a cardiac_symptom_rhythm)
  
  (SuregenNamedInstance s-palpitation palpitation :category :rythmDist :description "Palpitation")
  
  (SuregenConcept cardiac_irregularity :is-a cardiac_symptom_rhythm)
  
  (SETF AggRhythmComplaint 
    (MAKE-INSTANCE 'ItemListAggregator
      :AggregationMethod :eliminative-top_down
      :MethodToTemplate-alist '((:eliminative-top_down 
                                 (((NIL T) "Palpitationen")
                                  ((T NIL) "Herzstolpern"))))))
  
  (SuregenNamedInstance s-cardiac_irregularity cardiac_irregularity :category :rythmDist :description "Herzstolpern")
  
  (SuregenConcept rhythm_complaint :is-a SuregenComplaint
                  :has (presence (symptomlist :is-a SuregenItemList)))
  
  (ToDescribe :the :normal :of-a rhythm_complaint :as :NP
              :use (LET-IF* pre (IsNoneP (symptomlist it))
                            (Noun-Phrase :noun (my-intern 'Description) 
                                         :article :negative
                                         :numerus (my-intern 'DescribeAbsenceInPlural))))
  
  (SuregenNamedInstance i-rhythm_complaint rhythm_complaint
                        :conceptualAggregation AggRhythmComplaint 
                        :possibleSymptoms '(s-cardiac_irregularity s-palpitation)
                        :Description "Rhythmusbeschwerde"
                        :DescribeAbsenceInPlural :plural)
  
  ;;;(ToDescribe :a rhythm_complaint :as :MC
  ;;;            :use  (LET-IF* pre (IsNoneP (symptomlist it) T)
  ;;;                           :fail
  ;;;                           (Main-clause-simple :subject (Make-reference :patient :mode :personal)
  ;;;                                               :predicate "berichten"
  ;;;                                               :attribute (Noun-phrase 
  ;;;                                                           :noun (EnumFromList :neutral :positive
  ;;;                                                                               (Aggregate (conceptualAggregation it) 
  ;;;                                                                                          (symptomList it)
  ;;;                                                                                          (PossibleSymptoms it)))
  ;;;                                                           :preposition "ber")
  ;;;                                               :sentenceP T
  ;;;                                               :obligatoryItems (:attribute))))
  
  (ToDescribe :a rhythm_complaint :as :MC
              :use  (LET-IF* pre (IsNoneP (symptomlist it) T)
                             :fail
                             (Main-clause-simple :subject "es"
                                                 :predicate "kommen"
                                                 :attribute-pre (Noun-phrase 
                                                                 :noun (EnumFromList :neutral :positive
                                                                                     (Aggregate (conceptualAggregation it) 
                                                                                                (symptomList it)
                                                                                                (PossibleSymptoms it)))
                                                                 :preposition "zu")
                                                 :adverbial "bisweilen"
                                                 :tempus :praeteritum
                                                 :modus :conjunctive
                                                 :sentenceP T
                                                 :obligatoryItems (:attribute-pre) ;;; :constType (:splitpredicate)
                                                 :constType (:compsepAdvFirst))))
  
  ;;; ************************************************************************
  ;;; ************************     P5: Dyspnoe      **************************
  ;;; ************************************************************************ 
  
  (SuregenConcept Dyspnea :is-a cardiac_symptom
                  :has (atNight floors grade)
                  :has-intern ((description :INITFORM "Dyspnoe")))
  
;;;  (ToDescribe :the :normal :of-a Dyspnea :as :NP
;;;              :use (LET-IF* freq (EQUAL (my :grade) 1)
;;;                            "keine Dyspnoe"))
  
  (ToDescribe :the :grade :of-a dyspnea :as :NP
              :use (LET-IF* gradeQ (CASE (my :grade) 
                                     ((0 1) NIL)(2 "I") (3 "II") (4 "III") (5 "IV"))
                            (Phrase "Dyspnoe NYHA " gradeQ (WHEN (my :atNight) (Phrase comma "insbesondere nachts")))))
  
  (ToDescribe :the :exerciseLevel :of-a dyspnea :as :NP
              :use (LET-IF* floorsQ (NOT (my-ZEROP (my :floors)))
                            (Main-clause-simple :subject "Treppensteigen"
                                                :predicate "sein"
                                                :attribute (Noun-Phrase :noun  (Unit-Form (my :floors) "Etage" NIL T)
                                                                        :preposition "zu"
                                                                        :supplement-pre "bis")
                                                :adverbial2 "mglich")))
  
  (ToDescribe :a dyspnea :as :MC 
              :use (Parataxis :clause1 (Describes it :facet :grade :as :NP)
                              :clause2 (Describes it :facet :exerciseLevel :as :NP)))
  
  (SuregenNamedInstance i-dyspnea dyspnea)
  
  ;;; ************************************************************************
  ;;; ************************     P6: Edema      ****************************
  ;;; ************************************************************************ 
  
  (SuregenConcept cardiac_Edema :is-a cardiac_symptom
                  :has (grade laterality
                                  (location :is-a SuregenItemList))
                  :has-intern ((description :INITFORM "dem"))
                  :SemanticRoles ((quality (my :grade))
                                  (attribute (my :laterality))
                                  (concept (DescribeS it :facet :localization :as :NP))))
  
;;;  (ToDescribe :the :normal :of-a cardiac_Edema :as :NP
;;;              :use (LET-IF* freq (EQUAL (my :grade) 1)
;;;                            "keine deme"))
  
  (ToDescribe :the :localization :of-a cardiac_Edema :as :NP
              :use (SyntacticalSequenceTypeFromList :asyndetic NIL '((:numerus :plural))
                                                    (EnumFromList :emphasize :positive 
                                                                  (OR (Aggregate qualityaggobj (itemlist (Location it))
                                                                                 '((is-located "dem" there) "dem"))
                                                                      '("deme")) T)))
  
  (ToDescribe :a cardiac_Edema :as :MC
              :use (DescribeS it :by sf-qualification 
                              :as :NP-adverbial :extRoles '((qualAlist '((0 NIL) (1 NIL) (2 "gelegentlich")(3 "hufig") (4 "dauernd")))
                                                            (qualAList1 '((0 NIL) (1 "berwiegend links") (2 "berwiegend rechts") (3 "beidseits"))))
                              :spec '((:numerus :plural))))
  
  (SuregenNamedInstance i-cardiacEdema cardiac_edema :DescribeAbsenceInPlural :plural)
  
  ;;; ************************************************************************
  ;;; ************************     P7: nycturia     **************************
  ;;; ************************************************************************ 
  
  (SuregenConcept nycturia :is-a cardiac_symptom
                  :has (grade)
                  :has-intern ((description :INITFORM "Nykturie"))
                  :SemanticRoles ((quality (my :grade))
                                  (concept (my-intern 'Description))))
  
;;;  (ToDescribe :the :normal :of-a nycturia :as :NP
;;;              :use (LET-IF* freq (EQUAL (my :grade) 1)
;;;                            "keine Nykturie"))
  
  (ToDescribe :a nycturia :as :MC
              :use (DescribeS it :by sf-qualification :as :NP-adverbial
                              :extRoles '((qualAlist '((0 NIL) (1 NIL) (2 "selten")(3 "1-2 mal pro Nacht")
                                                       (4 "2-3mal pro Nacht")(5  "mehr als 3mal pro Nacht"))))))
  
  (SuregenNamedInstance i-nycturia nycturia)
  
  ;;; ************************************************************************
  ;;; *********************     P99: normal findings    **********************
  ;;; ************************************************************************ 
   
  (SuregenConcept NormalFindings :has-intern (findingsConcerned))
  
;;;  (ToDescribe :a NormalFindings :as :NPs
;;;              :use (EnumFromList :semitelegraphic :negative '(MAPDescribeS (my-intern 'findingsConcerned) :as :NP :facet :normal) NIL T))
;;;  
  (ToDescribe :a NormalFindings :as :NPs
              :use (Noun-phrase :noun (Aggregation COREDAGGOBJ  (MAPDescribeS (my-intern 'findingsConcerned) :as :NP :facet :normal))))
    
  
  (SuregenNamedInstance i-normalFindings NormalFindings 
                        :FindingsConcerned (LIST i-thoraxschmerz i-rhythm_complaint
                                                 i-dyspnea i-cardiacedema i-nycturia))
  
  
  
  ) ;;;EVAL-WHEN
